from enum import Enum
from sdgs_tools.dashboard.utils import make_str_to_enum

MAPPING = {
    "Tidak ada": "1",
    "Di kebun/sungai/drainase": "2",
    "Dibakar": "3",
    "Tempat sampah": "4",
    "Tempat sampah diangkut reguler": "5",
}


class PembuanganSampah(Enum):
    TIDAK_ADA = "1"
    KEBUN_SUNGAI_DRAINASE = "2"
    DIBAKAR = "3"
    TEMPAT_SAMPAH = "4"
    TEMPAT_SAMPAH_DIANGKUT = "5"

    from_str = classmethod(make_str_to_enum(MAPPING, "1"))



from enum import Enum
from sdgs_tools.dashboard.utils import make_str_to_enum

MAPPING = {
    "Listrik PLN": "1",
    "Listrik non PLN": "2",
    "Lampu minyak/lilin": "3",
    "Sumber penerangan lainnya": "4",
    "Tidak ada": "5",
}


class Penerangan(Enum):
    LISTRIK_PLN = "1"
    LISTRIK_NON_PLN = "2"
    LAMPU_MINYAK_LILIN = "3"
    LAINNYA = "4"
    TIDAK_ADA = "5"

    from_str = classmethod(make_str_to_enum(MAPPING, "1"))



from enum import Enum
from sdgs_tools.dashboard.utils import make_str_to_enum

MAPPING = {
    "Jamban sendiri": "1",
    "Jamban bersama/tetangga": "2",
    "Jamban umum": "3",
    "Lainnya": "other",
}


class FasilitasMck(Enum):
    SENDIRI = "1"
    BERSAMA = "2"
    UMUM = "3"
    LAINNYA = "other"

    from_str = classmethod(make_str_to_enum(MAPPING, "1"))



from enum import Enum
from sdgs_tools.dashboard.utils import make_str_to_enum

MAPPING = {
    "Milik Sendiri": "1",
    "Milik Orang Lain": "2",
    "Tanah Negara": "3",
    "Lainnya": "other",
}


class StatusLahan(Enum):
    MILIK_SENDIRI = "1"
    MILIK_ORANG_LAIN = "2"
    TANAH_NEGARA = "3"
    LAINNYA = "other"

    from_str = classmethod(make_str_to_enum(MAPPING, "1"))
